@@ -10,27 +10,24 @@ from dateutil.relativedelta import relativedelta
 from sql import Window
 from sql.functions import NthValue
 
-try:
-    from forex_python.converter import CurrencyRates, RatesNotAvailableError
-    get_rates = CurrencyRates(force_decimal=True).get_rates
-except ImportError:
-    CurrencyRates = get_rates = None
-
 from trytond.i18n import gettext
 from trytond.model import (
-    ModelView, ModelSQL, DeactivableMixin, fields, Unique, Check, SymbolMixin)
+    ModelView, ModelSQL, DeactivableMixin, fields, Unique, Check, SymbolMixin,
+    DigitsMixin)
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.rpc import RPC
 from trytond.pyson import Eval, If
 
+from .ecb import RatesNotAvailableError, get_rates
 from .exceptions import RateError
 from .ir import rate_decimal
 
 logger = logging.getLogger(__name__)
 
 
-class Currency(SymbolMixin, DeactivableMixin, ModelSQL, ModelView):
+class Currency(
+        SymbolMixin, DigitsMixin, DeactivableMixin, ModelSQL, ModelView):
     'Currency'
     __name__ = 'currency.currency'
     name = fields.Char('Name', required=True, translate=True,
@@ -299,7 +296,8 @@ class Cron(ModelSQL, ModelView):
     __name__ = 'currency.cron'
 
     source = fields.Selection(
-        [], "Source", required=True,
+        [('ecb', "European Central Bank")],
+        "Source", required=True,
         help="The external source for rates.")
     frequency = fields.Selection([
             ('daily', "Daily"),
@@ -339,8 +337,6 @@ class Cron(ModelSQL, ModelView):
         cls._buttons.update({
                 'run': {},
                 })
-        if CurrencyRates:
-            cls.source.selection.append(('ecb', "European Central Bank"))
 
     @classmethod
     def default_frequency(cls):
@@ -381,7 +377,8 @@ class Cron(ModelSQL, ModelView):
                 yield from self._rates(date)
             except CronFetchError:
                 logger.warning("Could not fetch rates temporary")
-                break
+                if date >= datetime.date.today():
+                    break
             except Exception:
                 logger.error("Fail to fetch rates", exc_info=True)
                 break
@@ -433,6 +430,8 @@ class Cron(ModelSQL, ModelView):
             if currency.code not in values:
                 continue
             value = values[currency.code]
+            if not isinstance(value, Decimal):
+                value = Decimal(value)
             rate = get_rate(currency)
             rate.rate = value.quantize(exp, rounding=rounding)
             yield rate
