@@ -7,7 +7,6 @@ import sys
 from argparse import ArgumentParser
 
 import pycountry
-from forex_python.converter import CurrencyCodes
 
 try:
     from progressbar import ProgressBar, Bar, ETA, SimpleProgress
@@ -37,6 +36,11 @@ def _get_language_codes():
         yield l.code
 
 
+def _remove_forbidden_chars(name):
+    from trytond.tools import remove_forbidden_chars
+    return remove_forbidden_chars(name)
+
+
 def get_currencies():
     Currency = Model.get('currency.currency')
     return {c.code: c for c in Currency.find([])}
@@ -45,7 +49,6 @@ def get_currencies():
 def update_currencies(currencies):
     print("Update currencies", file=sys.stderr)
     Currency = Model.get('currency.currency')
-    codes = CurrencyCodes()
 
     records = []
     for currency in _progress(pycountry.currencies):
@@ -53,10 +56,11 @@ def update_currencies(currencies):
         if code in currencies:
             record = currencies[code]
         else:
-            record = Currency(code=code)
-        record.name = currency.name
+            record = Currency(code=code, symbol=None)
+        record.name = _remove_forbidden_chars(currency.name)
         record.numeric_code = currency.numeric
-        record.symbol = codes.get_symbol(currency.alpha_3) or currency.alpha_3
+        if not record.symbol:
+            record.symbol = currency.alpha_3
         records.append(record)
 
     Currency.save(records)
@@ -78,7 +82,8 @@ def translate_currencies(currencies):
             records = []
             for currency in _progress(pycountry.currencies):
                 record = Currency(currencies[currency.alpha_3].id)
-                record.name = gnutranslation.gettext(currency.name)
+                record.name = _remove_forbidden_chars(
+                    gnutranslation.gettext(currency.name))
                 records.append(record)
             Currency.save(records)
 
